(function() {
	/*
	 * Mediaファイルのパスを一時保存する
	 */
	function setMediaFilePath(hiddenObjectId, path) {
		document.getElementById(hiddenObjectId).value = path;
	}

	/*
	 * 動画撮影
	 */
	captureVideo = function() {
		applican.capture.captureVideo(captureVideoSuccess, captureVideoError);
	}

	/*
	 * 動画撮影成功時のCallback処理
	 */
	function captureVideoSuccess(mediaFiles) {
		var dump = "動画の撮影に成功しました。\n";
		for (var i = 0; i < mediaFiles.length; i++) {
			dump += "path:";
			dump += mediaFiles[i].fullPath;
			setMediaFilePath("hidVideoFilePath", mediaFiles[i].fullPath);
		}
		//再生ボタンを非表示
		document.getElementById("videoPlayBtn").style.display = "block";
		
		document.getElementById("dumpAreaMedia").value = dump;
		alert(dump);
	}

	/*
	 * 動画撮影失敗時のCallback処理
	 * err.codeの説明
	 * 	・CaptureError.CAPTURE_INTERNAL_ERR = 0;
	 * 	　カメラまたはマイクが画像または音のキャプチャーに失敗した場合。
	 * 	・CaptureError.CAPTURE_APPLICATION_BUSY = 1;
	 * 	　カメラアプリまたはオーディオ録音アプリが現在他のキャプチャーリクエストを扱っている場合。
	 * 	・CaptureError.CAPTURE_INVALID_ARGUMENT = 2;
	 * 	　API の使用方法が不正であった場合 (例: limit パラメーターの値が1未満である) 。
	 * 	・CaptureError.CAPTURE_NO_MEDIA_FILES = 3;
	 * 	　ユーザーが何もキャプチャーせずにカメラアプリやオーディオ録音アプリを終了した場合。
	 * 	・CaptureError.CAPTURE_NOT_SUPPORTED = 20;
	 * 	　キャプチャー操作のリクエストがサポートされていない場合。
	 */
	function captureVideoError(err) {
		// ユーザーが何もキャプチャーせずにカメラアプリやオーディオ録音アプリを終了した場合
		if(err.code === 3) {
			return;
		}
		
		var dump = "動画の撮影に失敗しました。\n";
		dump    += "code:"    + err.code    + "\n";
		dump    += "message:" + err.message + "\n";
		document.getElementById("dumpAreaMedia").value = dump;
		alert(dump);
	}

	/*
	 * 動画を指定した位置に表示
	 * 	control: コントロールバーの表示フラグ
	 */
	playVideoOverlay = function(control) {
		var src = document.getElementById("hidVideoFilePath").value;
		var options = {
			top     : 10,
			left    : (document.documentElement.clientWidth-190) / 2,
			width   : 190,
			height  : 240,
			control : control
		};
		applican.video.play(src, playVideoOverlaySuccess, playVideoOverlayError, options);
		switchPlayBtnDisplay("videoPlayBtn","videStopBtn");
	}

	/*
	 * 動画再生成功時のCallback処理
	 */	
	function playVideoOverlaySuccess() {
		var dump = "動画再生しました。\n";
		document.getElementById("dumpAreaMedia").value =dump;
		switchPlayBtnDisplay("videoPlayBtn","videStopBtn");
	}

	/*
	 * 動画再生失敗時のCallback処理
	 */	
	function playVideoOverlayError(error) {
		var dump = "動画の再生に失敗しました。\n";
		dump    += "code:" + error.code + "\n";
		document.getElementById("dumpAreaMedia").value =dump;
	}

	/*
	 * 動画再生停止
	 */
	stopVideo = function() {
		applican.video.stop();
		switchPlayBtnDisplay("videoPlayBtn", "videStopBtn");
	}

	/*
	 * 再生ボタンの切り替え（生成←→停止）
	 */
	function switchPlayBtnDisplay(btnPlayId, btnStopId) {
		if(document.getElementById(btnStopId).style.display === "none") {
			document.getElementById(btnStopId).style.display = "block";
			document.getElementById(btnPlayId).style.display = "none";
		} else {
			document.getElementById(btnStopId).style.display = "none";
			document.getElementById(btnPlayId).style.display = "block";
		}
	}

	/********************* イベント登録 *********************/
	document.addEventListener("deviceready", function() {
		// 「動画撮影」ボタン押下処理
		document.getElementById("videoCaptureBtn").addEventListener("touchend", captureVideo, false);
		// 「動画再生」ボタン押下処理
		document.getElementById("videoPlayBtn").addEventListener("touchend", function() {
			playVideoOverlay(false);
			return false;
		}, false);
		// 「動画再生停止」ボタン押下処理
		document.getElementById("videStopBtn").addEventListener("touchend", stopVideo, false);
	}, false);
})();
